/// <reference types="node" />
import { EventEmitter } from 'events';
import { IDatabase, Interfaces } from './Types';
import { PoolConnection } from 'mysql';
/**
 * MYSQL interface that implements IDatabase
 */
export default class MySQL extends EventEmitter implements IDatabase {
    private readonly m_db;
    private m_tableOptions;
    /**
     * Creates a new instance of the class
     * @param host
     * @param port
     * @param user
     * @param password
     * @param database
     * @param connectionLimit
     */
    constructor(host: string, port: number, user: string, password: string, database: string, connectionLimit?: number);
    get hashType(): string;
    get blobType(): string;
    get uint32Type(): string;
    get uint64Type(): string;
    get tableOptions(): string | undefined;
    set tableOptions(value: string | undefined);
    get type(): Interfaces.DBType;
    on(event: 'error', listener: (error: Error) => void): this;
    on(event: 'acquire', listener: (connection: PoolConnection) => void): this;
    on(event: 'connection', listener: (connection: PoolConnection) => void): this;
    on(event: 'enqueue', listener: () => void): this;
    on(event: 'release', listener: (connection: PoolConnection) => void): this;
    on(event: 'ready', listener: () => void): this;
    /**
     * Creates the table with the given fields and options
     * @param name
     * @param fields
     * @param primaryKey
     * @param tableOptions
     */
    createTable(name: string, fields: Interfaces.ITableColumn[], primaryKey: string[], tableOptions?: string): Promise<void>;
    /**
     * Creates the SQL statements necessary to create a table with the given
     * fields and options
     * @param name
     * @param fields
     * @param primaryKey
     * @param tableOptions
     */
    prepareCreateTable(name: string, fields: Interfaces.ITableColumn[], primaryKey: string[], tableOptions?: string): {
        table: string;
        indexes: string[];
    };
    /**
     * Closes the database connection(s)
     */
    close(): Promise<void>;
    /**
     * Performs a query and returns the result
     * @param query
     * @param values
     */
    query<T = any>(query: string, values?: any[]): Promise<Interfaces.IQueryResult<T>>;
    /**
     * Constructs and executes the given queries in a transaction
     * @param queries
     */
    transaction(queries: Interfaces.IBulkQuery[]): Promise<void>;
    /**
     * Prepares a query to perform a multi-insert statement which is
     * far faster than a whole bunch of individual insert statements
     * @param table the table to perform the insert on
     * @param columns the columns to include in the insert
     * @param values the value of the columns
     */
    prepareMultiInsert(table: string, columns: string[], values?: Interfaces.IValueArray): string;
    /**
     * Prepares a query to perform a multi-update statement which is
     * based upon a multi-insert statement that performs an UPSERT
     * and this is a lot faster than a whole bunch of individual
     * update statements
     * @param table the table to perform the insert on
     * @param primaryKey the primary key(s) of the column for update purposes
     * @param columns the columns to update in the table
     * @param values the value of the columns
     */
    prepareMultiUpdate(table: string, primaryKey: string[], columns: string[], values?: Interfaces.IValueArray): string;
    private connection;
}
