/// <reference types="node" />
import { EventEmitter } from 'events';
import { PoolClient } from 'pg';
import { IDatabase, Interfaces } from './Types';
/**
 * Postgres database abstraction interface
 */
export default class Postgres extends EventEmitter implements IDatabase {
    private readonly m_pool;
    private m_tableOptions;
    /**
     * Creates a new instance of the class
     * @param host
     * @param port
     * @param username
     * @param password
     * @param database
     */
    constructor(host: string, port: number, username: string, password: string, database: string);
    /**
     * Returns the column type for the DB for a hash (ie. char(64))
     */
    get hashType(): string;
    /**
     * Returns the column type for the DB to store a hexadecimal blob of data
     */
    get blobType(): string;
    /**
     * Returns the column type for the DB to store a uint32_t value
     */
    get uint32Type(): string;
    /**
     * Returns the column type for the DB to store a uint64_t value
     */
    get uint64Type(): string;
    /**
     * Returns a string of additional options that need to be applied to tables
     * which may include ENGINE information, compression, etc depending on the DB system
     */
    get tableOptions(): string | undefined;
    set tableOptions(value: string | undefined);
    /**
     * Returns the database type
     */
    get type(): Interfaces.DBType;
    on(event: 'connect', listener: (client: PoolClient) => void): this;
    on(event: 'acquire', listener: (client: PoolClient) => void): this;
    on(event: 'remove', listener: (client: PoolClient) => void): this;
    on(event: 'error', listener: (error: Error) => void): this;
    on(event: 'ready', listener: () => void): this;
    /**
     * Closes the database connection(s)
     */
    close(): Promise<void>;
    /**
     * Creates the table with the given fields and options
     * @param name
     * @param fields
     * @param primaryKey
     * @param tableOptions
     */
    createTable(name: string, fields: Interfaces.ITableColumn[], primaryKey: string[], tableOptions?: string): Promise<void>;
    /**
     * Creates the SQL statements necessary to create a table with the given
     * fields and options
     * @param name
     * @param fields
     * @param primaryKey
     * @param tableOptions
     */
    prepareCreateTable(name: string, fields: Interfaces.ITableColumn[], primaryKey: string[], tableOptions?: string): {
        table: string;
        indexes: string[];
    };
    /**
     * Performs a query and returns the result
     * @param query
     * @param values
     * @param openClient permit specifying the pool client to use
     */
    query<T = any>(query: string, values?: any[], openClient?: PoolClient): Promise<Interfaces.IQueryResult<T>>;
    /**
     * Constructs and executes the given queries in a transaction
     * @param queries
     */
    transaction(queries: Interfaces.IBulkQuery[]): Promise<void>;
    /**
     * Prepares a query to perform a multi-insert statement which is
     * far faster than a whole bunch of individual insert statements
     * @param table the table to perform the insert on
     * @param columns the columns to include in the insert
     * @param values the value of the columns
     */
    prepareMultiInsert(table: string, columns: string[], values?: Interfaces.IValueArray): string;
    /**
     * Prepares a query to perform a multi-update statement which is
     * based upon a multi-insert statement that performs an UPSERT
     * and this is a lot faster than a whole bunch of individual
     * update statements
     * @param table the table to perform the insert on
     * @param primaryKey the primary key(s) of the column for update purposes
     * @param columns the columns to update in the table
     * @param values the value of the columns
     */
    prepareMultiUpdate(table: string, primaryKey: string[], columns: string[], values?: Interfaces.IValueArray): string;
}
